==> haskell-test-framework-hunit-0.3.0.2-674.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-hunit
version:              0.3.0.2
visibility:           public
id:                   test-framework-hunit-0.3.0.2-447Lid2bhEJ1Pivbk4FYyM
key:                  test-framework-hunit-0.3.0.2-447Lid2bhEJ1Pivbk4FYyM
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://batterseapower.github.io/test-framework/
synopsis:             HUnit support for the test-framework package.
description:          HUnit support for the test-framework package.
category:             Testing
abi:                  93faf22d329aa6b39c3e5aed9c795710
exposed:              True
exposed-modules:      Test.Framework.Providers.HUnit
import-dirs:          /usr/lib/ghc-9.2.8/site-local/test-framework-hunit-0.3.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-hunit
hs-libraries:         HStest-framework-hunit-0.3.0.2-447Lid2bhEJ1Pivbk4FYyM
depends:
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy base-4.16.4.0
    extensible-exceptions-0.1.1.4-D8VRIfPBfkhEPmMrxbU9lA
    test-framework-0.8.2.0-30XOAxDTBtoHUhSfJhyDW8

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-hunit-0.3.0.2-683.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-hunit
version:              0.3.0.2
visibility:           public
id:                   test-framework-hunit-0.3.0.2-4icY3MRfUCxHQCOH6xFXV4
key:                  test-framework-hunit-0.3.0.2-4icY3MRfUCxHQCOH6xFXV4
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://batterseapower.github.io/test-framework/
synopsis:             HUnit support for the test-framework package.
description:          HUnit support for the test-framework package.
category:             Testing
abi:                  c01cadc570070a72a410ded3aac38fb5
exposed:              True
exposed-modules:      Test.Framework.Providers.HUnit
import-dirs:          /usr/lib/ghc-9.2.8/site-local/test-framework-hunit-0.3.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-hunit
hs-libraries:         HStest-framework-hunit-0.3.0.2-4icY3MRfUCxHQCOH6xFXV4
depends:
    HUnit-1.6.2.0-4gkKXmDNQefEQuipMNWISY base-4.16.4.0
    extensible-exceptions-0.1.1.4-D8VRIfPBfkhEPmMrxbU9lA
    test-framework-0.8.2.0-5uvP7zRH3Y54oipi1F1CKa

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
